import {
  select,
  geoPath,
  geoCentroid,
  geoNaturalEarth1,
  zoom,
  event,
  scaleOrdinal,
  schemeSpectral,
  scaleSqrt,
  max,
  format 
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { sizeLegend } from './sizeLegend';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);
const radiusValue=d => d.properties['2018'];

const g = svg.append('g');

const colorLegendG = svg.append('g')
    .attr('transform', `translate(40,310)`);

g.append('path')
    .attr('class', 'sphere')
    .attr('d', pathGenerator({type: 'Sphere'}));

svg.call(zoom().on('zoom', () => {
  g.attr('transform', event.transform);
}));

const populationFormat=format(',');

loadAndProcessData().then(countries => {
  //圆圈的大小
  const sizeScale=scaleSqrt()
    .domain([0,max(countries.features,radiusValue)])
    .range([0,33]);

  g.selectAll('path').data(countries.features)
    .enter().append('path')
      .attr('class', 'country')
      .attr('d', pathGenerator)
      .attr('fill', d => d.properties['2018']?'#e6b9f8':'#75ffd5')
    .append('title')
      .text(d => 
           isNaN(radiusValue(d))
          ? 'Missing data'
          : [
            d.properties['Region, subregion, country or area *'],
            populationFormat(radiusValue(d))
          ].join(': ')
      );
  countries.featuresWithPopulation.forEach(d => {
     d.properties.projected=projection(geoCentroid(d));
  });
  
  g.selectAll('circle').data(countries.featuresWithPopulation)
    .enter().append('circle')
      .attr('class', 'country-circle')
      .attr('cx',d => d.properties.projected[0])
      .attr('cy',d => d.properties.projected[1])
      .attr('r',d => sizeScale(radiusValue(d)));
  
  g.append('g')
     .attr('transform',`translate(45,125)`)
      .call(sizeLegend,{     //调用sizeLegend.js,并初始化参数
        sizeScale,
        spacing:45,
   		  textOffset:10,
        numTicks:5,
        tickFormat:populationFormat
     })
      .append('text')  //鼠标触摸到某个国家，显示该国家的信息
         .attr('class','legend-title')
         .text('pop